@@ -5,6 +5,7 @@ import (
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 
 	"github.com/spf13/cobra"
 )
@@ -39,15 +40,18 @@ Migrates the ~/myconfig.omp.json config file to TOML and writes the result to yo
 A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		env := &runtime.Terminal{
-			CmdFlags: &runtime.Flags{
-				Config:  configFlag,
-				Migrate: true,
-			},
+		configFile := config.Path(configFlag)
+		cfg := config.Load(configFile, shell.GENERIC, true)
+
+		flags := &runtime.Flags{
+			Config:  configFile,
+			Migrate: true,
 		}
-		env.Init()
+
+		env := &runtime.Terminal{}
+		env.Init(flags)
 		defer env.Close()
-		cfg := config.Load(env)
+
 		if write {
 			cfg.BackupAndMigrate()
 			return
