@@ -1,14 +1,12 @@
 package segments
 
 import (
-	"github.com/jandedobbeleer/oh-my-posh/platform"
-	"github.com/jandedobbeleer/oh-my-posh/platform/battery"
-	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/battery"
 )
 
 type Battery struct {
-	props properties.Properties
-	env   platform.Environment
+	base
 
 	*battery.Info
 	Error string
@@ -83,8 +81,3 @@ func (b *Battery) enabledWhileError(err error) bool {
 	b.State = battery.Full
 	return true
 }
-
-func (b *Battery) Init(props properties.Properties, env platform.Environment) {
-	b.props = props
-	b.env = env
-}
